@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::OutputStartup;
 
-our $DATE = '2017-07-13'; # DATE
-our $VERSION = '0.010'; # VERSION
+our $DATE = '2017-08-01'; # DATE
+our $VERSION = '0.011'; # VERSION
 
 use 5.010001;
 use strict;
@@ -29,6 +29,7 @@ our %output_modules = (
     LogAny => {},
     LogDispatchOutput => { output => 'ArrayWithLimits', args => {array => $ary} },
     Composite => { outputs => {Screen => {conf=>{}}, File => {conf=>{path=>$fname}}} },
+    Syslog => { ident => 'test' },
 );
 
 our $scenario = {
@@ -74,7 +75,7 @@ Bencher::Scenario::LogGer::OutputStartup
 
 =head1 VERSION
 
-This document describes version 0.010 of Bencher::Scenario::LogGer::OutputStartup (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-07-13.
+This document describes version 0.011 of Bencher::Scenario::LogGer::OutputStartup (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-08-01.
 
 =head1 SYNOPSIS
 
@@ -96,7 +97,7 @@ Packaging a benchmark script as a Bencher scenario makes it convenient to includ
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Log::ger::Output::Array> 0.016
+L<Log::ger::Output::Array> 0.020
 
 L<Log::ger::Output::ArrayWithLimits> 0.001
 
@@ -114,11 +115,13 @@ L<Log::ger::Output::LogAny> 0.006
 
 L<Log::ger::Output::LogDispatchOutput> 0.001
 
-L<Log::ger::Output::Null> 0.016
+L<Log::ger::Output::Null> 0.020
 
 L<Log::ger::Output::Screen> 0.005
 
-L<Log::ger::Output::String> 0.016
+L<Log::ger::Output::String> 0.020
+
+L<Log::ger::Output::Syslog> 0.001
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -272,44 +275,58 @@ L<Log::ger::Output::String>
 
 
 
+=item * load-Syslog (command)
+
+L<Log::ger::Output::Syslog>
+
+
+
+=item * init-with-Syslog (command)
+
+L<Log::ger::Output::Syslog>
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
+Run on: perl: I<< v5.26.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m LogGer::OutputStartup >>):
 
  #table1#
- +-----------------------------+-----------+-----------+------------+-----------+---------+
- | participant                 | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
- +-----------------------------+-----------+-----------+------------+-----------+---------+
- | init-with-FileWriteRotate   |        19 |      54   |        1   |   0.00014 |      20 |
- | init-with-LogDispatchOutput |        31 |      32   |        1.7 | 9.1e-05   |      22 |
- | init-with-LogAny            |        46 |      22   |        2.5 | 7.5e-05   |      21 |
- | init-with-Composite         |        48 |      21   |        2.6 | 9.8e-05   |      20 |
- | init-with-DirWriteRotate    |        51 |      19   |        2.8 | 8.4e-05   |      20 |
- | init-with-String            |        66 |      15   |        3.5 | 4.9e-05   |      20 |
- | init-with-Null              |        66 |      15   |        3.6 | 5.3e-05   |      20 |
- | init-with-Screen            |        67 |      15   |        3.6 | 5.1e-05   |      21 |
- | init-with-File              |        67 |      15   |        3.6 | 4.2e-05   |      20 |
- | init-with-Array             |        67 |      15   |        3.6 | 3.3e-05   |      21 |
- | init-with-ArrayWithLimits   |        67 |      15   |        3.6 | 2.2e-05   |      20 |
- | init-with-Callback          |        68 |      15   |        3.7 | 7.3e-05   |      20 |
- | load-Screen                 |        75 |      13   |        4   | 3.7e-05   |      20 |
- | load-LogDispatchOutput      |        76 |      13   |        4.1 | 5.7e-05   |      21 |
- | load-Composite              |        95 |      11   |        5.1 |   3e-05   |      20 |
- | load-Callback               |       100 |       9.8 |        5.5 | 3.9e-05   |      20 |
- | load-DirWriteRotate         |       100 |       9.6 |        5.6 | 2.4e-05   |      20 |
- | load-File                   |       100 |       9.6 |        5.6 | 2.6e-05   |      20 |
- | load-ArrayWithLimits        |       100 |       9.6 |        5.6 | 3.4e-05   |      20 |
- | load-LogAny                 |       110 |       9.5 |        5.7 | 1.4e-05   |      21 |
- | load-FileWriteRotate        |       110 |       9.5 |        5.7 | 1.5e-05   |      20 |
- | load-String                 |       110 |       9.5 |        5.7 | 5.2e-05   |      20 |
- | load-Array                  |       110 |       9.5 |        5.7 | 1.8e-05   |      20 |
- | load-Null                   |       140 |       7.1 |        7.6 | 2.4e-05   |      20 |
- | baseline                    |       150 |       6.7 |        8   | 1.7e-05   |      20 |
- +-----------------------------+-----------+-----------+------------+-----------+---------+
+ +-----------------------------+-----------+-----------+------------+----------+---------+
+ | participant                 | rate (/s) | time (ms) | vs_slowest |  errors  | samples |
+ +-----------------------------+-----------+-----------+------------+----------+---------+
+ | init-with-LogDispatchOutput |       8.7 |     120   |        1   |   0.0002 |      23 |
+ | init-with-FileWriteRotate   |      20   |      50   |        2.3 |   0.0001 |      20 |
+ | init-with-Syslog            |      30   |      33   |        3.5 |   6e-05  |      21 |
+ | init-with-LogAny            |      49   |      20   |        5.7 | 6.1e-05  |      20 |
+ | init-with-Composite         |      53   |      19   |        6.1 | 5.9e-05  |      21 |
+ | init-with-DirWriteRotate    |      58   |      17   |        6.7 | 4.1e-05  |      20 |
+ | init-with-File              |      74   |      13   |        8.6 | 3.4e-05  |      21 |
+ | init-with-Screen            |      75   |      13   |        8.6 | 5.4e-05  |      21 |
+ | init-with-Callback          |      75   |      13   |        8.7 | 3.8e-05  |      20 |
+ | init-with-String            |      75   |      13   |        8.7 | 2.3e-05  |      20 |
+ | init-with-Array             |      76   |      13   |        8.7 | 3.9e-05  |      21 |
+ | init-with-ArrayWithLimits   |      76   |      13   |        8.7 | 2.5e-05  |      20 |
+ | init-with-Null              |      76   |      13   |        8.8 |   3e-05  |      21 |
+ | load-Screen                 |      83   |      12   |        9.6 | 3.8e-05  |      20 |
+ | load-LogDispatchOutput      |      86   |      12   |        9.9 | 3.3e-05  |      20 |
+ | load-Composite              |     110   |       9.3 |       12   | 4.9e-05  |      20 |
+ | load-String                 |     120   |       8.5 |       14   |   6e-05  |      20 |
+ | load-Syslog                 |     120   |       8.5 |       14   | 2.9e-05  |      20 |
+ | load-Array                  |     120   |       8.5 |       14   |   7e-05  |      20 |
+ | load-LogAny                 |     120   |       8.4 |       14   | 2.3e-05  |      20 |
+ | load-DirWriteRotate         |     120   |       8.4 |       14   | 4.5e-05  |      20 |
+ | load-File                   |     120   |       8.3 |       14   | 3.7e-05  |      20 |
+ | load-ArrayWithLimits        |     120   |       8.3 |       14   | 2.1e-05  |      20 |
+ | load-FileWriteRotate        |     120   |       8.3 |       14   | 4.1e-05  |      20 |
+ | load-Callback               |     120   |       8.3 |       14   | 1.3e-05  |      20 |
+ | load-Null                   |     170   |       6   |       19   | 4.5e-05  |      20 |
+ | baseline                    |     170   |       5.8 |       20   | 5.7e-05  |      20 |
+ +-----------------------------+-----------+-----------+------------+----------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m LogGer::OutputStartup --module-startup >>):
@@ -318,19 +335,20 @@ Benchmark module startup overhead (C<< bencher -m LogGer::OutputStartup --module
  +-------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
  | participant                         | proc_private_dirty_size (kB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +-------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | Log::ger::Output::Screen            | 864                          | 4.2                | 16             |      14   |                    7.3 |        1   | 6.7e-05 |      20 |
- | Log::ger::Output::LogDispatchOutput | 860                          | 4.2                | 16             |      13   |                    6.3 |        1   | 3.3e-05 |      20 |
- | Log::ger::Output::Composite         | 860                          | 4.1                | 16             |      11   |                    4.3 |        1.3 |   3e-05 |      20 |
- | Log::ger::Output::LogAny            | 1000                         | 4.3                | 16             |       9.7 |                    3   |        1.4 | 2.8e-05 |      20 |
- | Log::ger::Output::File              | 864                          | 4.1                | 16             |       9.7 |                    3   |        1.4 | 3.5e-05 |      20 |
- | Log::ger::Output::String            | 864                          | 4.2                | 16             |       9.6 |                    2.9 |        1.4 | 2.2e-05 |      23 |
- | Log::ger::Output::ArrayWithLimits   | 856                          | 4.2                | 16             |       9.6 |                    2.9 |        1.4 | 2.5e-05 |      20 |
- | Log::ger::Output::Callback          | 856                          | 4.1                | 16             |       9.5 |                    2.8 |        1.4 | 2.6e-05 |      20 |
- | Log::ger::Output::DirWriteRotate    | 868                          | 4.1                | 16             |       9.4 |                    2.7 |        1.4 | 1.5e-05 |      22 |
- | Log::ger::Output::Array             | 860                          | 4.2                | 16             |       9.4 |                    2.7 |        1.4 | 1.2e-05 |      20 |
- | Log::ger::Output::FileWriteRotate   | 1004                         | 4.3                | 16             |       9.3 |                    2.6 |        1.4 | 1.4e-05 |      20 |
- | Log::ger::Output::Null              | 860                          | 4.1                | 16             |       7   |                    0.3 |        1.9 |   1e-05 |      20 |
- | perl -e1 (baseline)                 | 844                          | 4.1                | 16             |       6.7 |                    0   |        2   | 2.5e-05 |      20 |
+ | Log::ger::Output::LogDispatchOutput | 844                          | 4.3                | 20             |      12   |     6                  |        1   |   5e-05 |      20 |
+ | Log::ger::Output::Screen            | 844                          | 4.2                | 20             |      12   |     6                  |        1   | 1.7e-05 |      20 |
+ | Log::ger::Output::Composite         | 840                          | 4.2                | 20             |       9.2 |     3.2                |        1.3 |   4e-05 |      21 |
+ | Log::ger::Output::Syslog            | 840                          | 4.2                | 20             |       8.5 |     2.5                |        1.4 | 4.1e-05 |      21 |
+ | Log::ger::Output::ArrayWithLimits   | 840                          | 4.3                | 20             |       8.4 |     2.4                |        1.4 | 4.4e-05 |      20 |
+ | Log::ger::Output::File              | 844                          | 4.2                | 20             |       8.4 |     2.4                |        1.4 |   5e-05 |      20 |
+ | Log::ger::Output::Callback          | 840                          | 4.2                | 20             |       8.3 |     2.3                |        1.4 | 2.6e-05 |      20 |
+ | Log::ger::Output::FileWriteRotate   | 936                          | 4.3                | 20             |       8.3 |     2.3                |        1.4 | 2.8e-05 |      20 |
+ | Log::ger::Output::DirWriteRotate    | 840                          | 4.2                | 20             |       8.3 |     2.3                |        1.4 | 2.3e-05 |      20 |
+ | Log::ger::Output::String            | 840                          | 4.3                | 20             |       8.2 |     2.2                |        1.4 | 2.9e-05 |      20 |
+ | Log::ger::Output::LogAny            | 932                          | 4.4                | 20             |       8.2 |     2.2                |        1.5 | 2.5e-05 |      20 |
+ | Log::ger::Output::Array             | 836                          | 4.3                | 20             |       8.2 |     2.2                |        1.5 | 1.7e-05 |      20 |
+ | Log::ger::Output::Null              | 840                          | 4.2                | 20             |       5.9 |    -0.0999999999999996 |        2   | 4.8e-05 |      20 |
+ | perl -e1 (baseline)                 | 572                          | 4                  | 20             |       6   |     0                  |        2   | 5.9e-05 |      20 |
  +-------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
