@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::StringLevel;
 
-our $DATE = '2017-07-13'; # DATE
-our $VERSION = '0.010'; # VERSION
+our $DATE = '2017-08-01'; # DATE
+our $VERSION = '0.011'; # VERSION
 
 use 5.010001;
 use strict;
@@ -38,7 +38,7 @@ Bencher::Scenario::LogGer::StringLevel - Benchmark string_level()
 
 =head1 VERSION
 
-This document describes version 0.010 of Bencher::Scenario::LogGer::StringLevel (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-07-13.
+This document describes version 0.011 of Bencher::Scenario::LogGer::StringLevel (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-08-01.
 
 =head1 SYNOPSIS
 
@@ -60,7 +60,7 @@ Packaging a benchmark script as a Bencher scenario makes it convenient to includ
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Log::ger::Util> 0.016
+L<Log::ger::Util> 0.020
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -88,16 +88,16 @@ Function call template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
+Run on: perl: I<< v5.26.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m LogGer::StringLevel >>):
 
  #table1#
  +---------+-----------+-----------+------------+---------+---------+
- | dataset | rate (/s) | time (μs) | vs_slowest |  errors | samples |
+ | dataset | rate (/s) | time (ns) | vs_slowest |  errors | samples |
  +---------+-----------+-----------+------------+---------+---------+
- | 1       |    567570 |   1.7619  |    1       | 1.1e-11 |      20 |
- | warn    |   4062240 |   0.24617 |    7.15727 |   0     |      20 |
+ | 1       |    760000 |      1300 |       1    |   3e-09 |      25 |
+ | warn    |   4240000 |       236 |       5.57 | 1.4e-10 |      20 |
  +---------+-----------+-----------+------------+---------+---------+
 
 
@@ -107,8 +107,8 @@ Benchmark module startup overhead (C<< bencher -m LogGer::StringLevel --module-s
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
  | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | Log::ger::Util      | 0.82                         | 4.2                | 16             |      13   |                    5.9 |        1   |   3e-05 |      20 |
- | perl -e1 (baseline) | 1.3                          | 4.7                | 17             |       7.1 |                    0   |        1.8 | 2.3e-05 |      20 |
+ | Log::ger::Util      | 0.56                         | 4                  | 20             |      11   |                    5.3 |          1 | 3.7e-05 |      20 |
+ | perl -e1 (baseline) | 1.3                          | 4.7                | 20             |       5.7 |                    0   |          2 | 3.7e-05 |      20 |
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
