@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::NullOutput;
 
-our $VERSION = "0.010"; # VERSION
+our $VERSION = 0.011; # VERSION
 
 our $results = [
   [
@@ -8,108 +8,132 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.00066,
-        participant => "Log::Log4perl::Tiny-1mil_trace",
-        rate => 0.792,
+        errors => 0.021,
+        participant => "Log::Contextual+Log4perl",
+        rate => 0.17,
         samples => 6,
-        time => 1260,
+        time => 5.8,
         vs_slowest => 1,
       },
       {
-        errors => 0.0012,
+        errors => 0.0056,
+        participant => "Log::Contextual+SimpleLogger",
+        rate => 0.177,
+        samples => 6,
+        time => 5.65,
+        vs_slowest => 1.02,
+      },
+      {
+        errors => 0.00066,
+        participant => "Log::Log4perl::Tiny-1mil_trace",
+        rate => 0.847,
+        samples => 6,
+        time => 1.18,
+        vs_slowest => 4.88,
+      },
+      {
+        errors => 0.00031,
+        participant => "Log::Dispatchouli",
+        rate => 1.25,
+        samples => 6,
+        time => 0.803,
+        vs_slowest => 7.18,
+      },
+      {
+        errors => 0.0011,
         participant => "Log::Any-null_adapter-1mil_log_trace",
-        rate => 1.3,
-        samples => 6,
-        time => 760,
-        vs_slowest => 1.7,
+        rate => 1.7,
+        samples => 7,
+        time => 0.6,
+        vs_slowest => 9.6,
       },
       {
-        errors => 0.0015,
+        errors => 0.0019,
         participant => "Log::Fast-1mil_is_debug",
-        rate => 1.9,
+        rate => 2.2,
         samples => 6,
-        time => 520,
-        vs_slowest => 2.4,
-      },
-      {
-        errors => 0.0075,
-        participant => "Log::Any-no_adapter-1mil_is_trace",
-        rate => 2,
-        samples => 6,
-        time => 500,
-        vs_slowest => 3,
-      },
-      {
-        errors => 0.00099,
-        participant => "Log::Any-null_adapter-1mil_is_trace",
-        rate => 2.3,
-        samples => 8,
-        time => 440,
-        vs_slowest => 2.9,
-      },
-      {
-        errors => 0.00029,
-        participant => "Log::Log4perl-easy-1mil_trace",
-        rate => 3.1,
-        samples => 6,
-        time => 323,
-        vs_slowest => 3.92,
-      },
-      {
-        errors => 0.00057,
-        participant => "Log::Any-no_adapter-1mil_log_trace",
-        rate => 6.1,
-        samples => 6,
-        time => 160,
-        vs_slowest => 7.7,
-      },
-      {
-        errors => 0.00041,
-        participant => "Log::Fast-1mil_DEBUG",
-        rate => 6.5,
-        samples => 6,
-        time => 150,
-        vs_slowest => 8.2,
-      },
-      {
-        errors => 0.0013,
-        participant => "Log::ger+LGP:MutilevelLog-1mil_log_6",
-        rate => 8,
-        samples => 6,
-        time => 100,
-        vs_slowest => 10,
-      },
-      {
-        errors => 0.001,
-        participant => "Log::ger+LGP:MutilevelLog-1mil_log_trace",
-        rate => 8.8,
-        samples => 8,
-        time => 110,
-        vs_slowest => 11,
-      },
-      {
-        errors => 0.00028,
-        participant => "Log::ger-1mil_log_trace",
-        rate => 10,
-        samples => 6,
-        time => 97,
+        time => 0.46,
         vs_slowest => 13,
       },
       {
-        errors => 0.00028,
-        participant => "Log::ger-1mil_log_is_trace",
-        rate => 11,
+        errors => 0.00084,
+        participant => "Log::Any-no_adapter-1mil_is_trace",
+        rate => 2.5,
         samples => 6,
-        time => 92,
-        vs_slowest => 14,
+        time => 0.4,
+        vs_slowest => 15,
       },
       {
-        errors => 0.00032,
-        participant => "Log::ger+LGP:OptAway-1mil_log_trace",
-        rate => 21,
+        errors => 0.0017,
+        participant => "Log::Any-null_adapter-1mil_is_trace",
+        rate => 2.5,
         samples => 6,
-        time => 49,
-        vs_slowest => 26,
+        time => 0.4,
+        vs_slowest => 15,
+      },
+      {
+        errors => 0.00022,
+        participant => "Log::Log4perl-easy-1mil_trace",
+        rate => 3.16,
+        samples => 6,
+        time => 0.316,
+        vs_slowest => 18.2,
+      },
+      {
+        errors => 0.00051,
+        participant => "Log::Any-no_adapter-1mil_log_trace",
+        rate => 6.4,
+        samples => 6,
+        time => 0.16,
+        vs_slowest => 37,
+      },
+      {
+        errors => 0.0006,
+        participant => "Log::Fast-1mil_DEBUG",
+        rate => 6.4,
+        samples => 7,
+        time => 0.16,
+        vs_slowest => 37,
+      },
+      {
+        errors => 0.0023,
+        participant => "Log::ger+LGP:MutilevelLog-1mil_log_trace",
+        rate => 9,
+        samples => 7,
+        time => 0.1,
+        vs_slowest => 50,
+      },
+      {
+        errors => 0.00041,
+        participant => "Log::ger+LGP:MutilevelLog-1mil_log_6",
+        rate => 9.3,
+        samples => 6,
+        time => 0.11,
+        vs_slowest => 53,
+      },
+      {
+        errors => 3.3e-05,
+        participant => "Log::ger-1mil_log_is_trace",
+        rate => 9.62,
+        samples => 6,
+        time => 0.104,
+        vs_slowest => 55.4,
+      },
+      {
+        errors => 0.00078,
+        participant => "Log::ger-1mil_log_trace",
+        rate => 10,
+        samples => 7,
+        time => 0.099,
+        vs_slowest => 58,
+      },
+      {
+        errors => 0.0002,
+        participant => "Log::ger+LGP:OptAway-1mil_log_trace",
+        rate => 24,
+        samples => 6,
+        time => 0.042,
+        vs_slowest => 140,
       },
     ],
     {
@@ -119,6 +143,7 @@ our $results = [
                                             scenario_module => "LogGer::NullOutput",
                                           },
       "func.bencher_version"           => undef,
+      "func.code_startup"              => undef,
       "func.cpu_info"                  => [
                                             {
                                               address_width                => 64,
@@ -157,7 +182,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -180,7 +204,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -188,20 +211,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -210,30 +229,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2031.695,
-                                              stepping                     => 4,
+                                              speed                        => 3247.492,
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -272,7 +277,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -295,7 +299,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -303,20 +306,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -325,30 +324,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => "2099.890",
-                                              stepping                     => 4,
+                                              speed                        => 3250.035,
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -387,7 +372,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -410,7 +394,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -418,20 +401,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -440,30 +419,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => "2100.000",
-                                              stepping                     => 4,
+                                              speed                        => 3256.816,
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -502,7 +467,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -525,7 +489,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -533,20 +496,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -555,85 +514,71 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2010.968,
-                                              stepping                     => 4,
+                                              speed                        => 3245.675,
+                                              stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 42.2324140071869,
+      "func.elapsed_time"              => 136.550081968307,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
-                                            "__PACKAGE__" => 1.039,
+                                            "__PACKAGE__" => "1.040",
                                             "Bencher::Scenario::LogGer::NullOutput" => undef,
-                                            "Benchmark::Dumb" => "0.10",
+                                            "Benchmark::Dumb" => 0.111,
                                             "Devel::Platform::Info" => 0.16,
-                                            "Log::Any" => 1.042,
+                                            "Log::Any" => 1.049,
                                             "Log::Fast" => "v2.0.0",
-                                            "Log::ger" => 0.016,
-                                            "Log::ger::Plugin::MultilevelLog" => 0.016,
+                                            "Log::ger" => "0.020",
+                                            "Log::ger::Plugin::MultilevelLog" => "0.020",
                                             "Log::ger::Plugin::OptAway" => 0.004,
-                                            "Log::Log4perl" => 1.47,
+                                            "Log::Log4perl" => 1.49,
                                             "Log::Log4perl::Tiny" => "1.4.0",
-                                            "perl" => "v5.24.0",
+                                            "perl" => "v5.26.0",
                                             "Sys::Info" => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
-      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 12]],
+      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 15]],
       "func.platform_info"             => {
                                             archname => "x86_64",
-                                            codename => "rosa",
+                                            codename => "jessie",
                                             is32bit  => 0,
                                             is64bit  => 1,
-                                            kernel   => "linux-3.19.0-32-generic",
+                                            kernel   => "linux-3.16.0-4-amd64",
                                             kname    => "Linux",
-                                            kvers    => "3.19.0-32-generic",
+                                            kvers    => "3.16.0-4-amd64",
                                             osflag   => "linux",
-                                            oslabel  => "LinuxMint",
+                                            oslabel  => "Debian",
                                             osname   => "GNU/Linux",
-                                            osvers   => 17.3,
+                                            osvers   => "8.0",
                                             source   => {
                                                           "cat /etc/.issue" => "",
-                                                          "cat /etc/issue"  => "Linux Mint 17.3 Rosa \\n \\l",
-                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 17.3 Rosa\nRelease:\t17.3\nCodename:\trosa",
-                                                          "uname -a"        => "Linux backpacker 3.19.0-32-generic #37~14.04.1-Ubuntu SMP Thu Oct 22 09:41:40 UTC 2015 x86_64 x86_64 x86_64 GNU/Linux",
+                                                          "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
+                                                          "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
+                                                          "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.36-1+deb8u2 (2016-10-19) x86_64 GNU/Linux",
                                                           "uname -m"        => "x86_64",
                                                           "uname -o"        => "GNU/Linux",
-                                                          "uname -r"        => "3.19.0-32-generic",
+                                                          "uname -r"        => "3.16.0-4-amd64",
                                                           "uname -s"        => "Linux",
                                                         },
                                           },
       "func.precision"                 => 6,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::NullOutput",
-      "func.scenario_module_md5sum"    => "c1018c0fec5ee4836d66f780358897a5",
-      "func.scenario_module_mtime"     => 1498961728,
-      "func.scenario_module_sha1sum"   => "039e31b9d8b409b777cec032562b21d37edab395",
-      "func.scenario_module_sha256sum" => "2c90a1da76fe91703dde63d313d2d6c2813756ff795c84aa312c5475396a63bf",
-      "func.time_end"                  => 1499940790.05205,
-      "func.time_factor"               => 1000,
-      "func.time_start"                => 1499940747.81964,
+      "func.scenario_module_md5sum"    => "c34f6af7d97c52ab6574bb4d5b5dee59",
+      "func.scenario_module_mtime"     => 1501567073,
+      "func.scenario_module_sha1sum"   => "eaac62da5f7838e0171992fff2dcbddf169a7de4",
+      "func.scenario_module_sha256sum" => "45aae8b616216d6db42208ee8ebad6d06ba4478709036fbe16222d9d1c236bc2",
+      "func.time_end"                  => 1501567515.4285,
+      "func.time_factor"               => 1,
+      "func.time_start"                => 1501567378.87842,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
-      "table.field_units"              => [undef, undef, "/s", "ms"],
+      "table.field_units"              => [undef, undef, "/s"],
       "table.fields"                   => [
                                             "participant",
                                             "dataset",
