@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::NumericLevel;
 
-our $VERSION = "0.010"; # VERSION
+our $VERSION = 0.011; # VERSION
 
 our $results = [
   [
@@ -9,19 +9,19 @@ our $results = [
     [
       {
         dataset    => "warn",
-        errors     => 1.1e-11,
-        rate       => 1955000,
+        errors     => 9.3e-11,
+        rate       => 2170000,
         samples    => 20,
-        time       => 511.4,
+        time       => 461,
         vs_slowest => 1,
       },
       {
         dataset    => 1,
-        errors     => 3.8e-10,
-        rate       => 2330000,
-        samples    => 28,
-        time       => 430,
-        vs_slowest => 1.19,
+        errors     => 9e-10,
+        rate       => 2600000,
+        samples    => 20,
+        time       => 380,
+        vs_slowest => 1.2,
       },
     ],
     {
@@ -31,6 +31,7 @@ our $results = [
                                             scenario_module => "LogGer::NumericLevel",
                                           },
       "func.bencher_version"           => undef,
+      "func.code_startup"              => undef,
       "func.cpu_info"                  => [
                                             {
                                               address_width                => 64,
@@ -69,7 +70,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -92,7 +92,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -100,20 +99,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -122,30 +117,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => "2199.640",
-                                              stepping                     => 4,
+                                              speed                        => 3295.687,
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -184,7 +165,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -207,7 +187,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -215,20 +194,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -237,30 +212,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2200.078,
-                                              stepping                     => 4,
+                                              speed                        => 3254.152,
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -299,7 +260,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -322,7 +282,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -330,20 +289,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -352,30 +307,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2199.968,
-                                              stepping                     => 4,
+                                              speed                        => 3287.089,
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -414,7 +355,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -437,7 +377,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -445,20 +384,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -467,77 +402,63 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2132.867,
-                                              stepping                     => 4,
+                                              speed                        => 3248.218,
+                                              stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.0576159954071045,
+      "func.elapsed_time"              => 0.0521581172943115,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
-                                            "__PACKAGE__" => 1.039,
+                                            "__PACKAGE__" => "1.040",
                                             "Bencher::Scenario::LogGer::NumericLevel" => undef,
-                                            "Benchmark::Dumb" => "0.10",
+                                            "Benchmark::Dumb" => 0.111,
                                             "Devel::Platform::Info" => 0.16,
-                                            "Log::ger::Util" => 0.016,
-                                            "perl" => "v5.24.0",
+                                            "Log::ger::Util" => "0.020",
+                                            "perl" => "v5.26.0",
                                             "Sys::Info" => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
       "func.permute"                   => ["perl", ["perl"], "participant", [0], "dataset", [0, 1]],
       "func.platform_info"             => {
                                             archname => "x86_64",
-                                            codename => "rosa",
+                                            codename => "jessie",
                                             is32bit  => 0,
                                             is64bit  => 1,
-                                            kernel   => "linux-3.19.0-32-generic",
+                                            kernel   => "linux-3.16.0-4-amd64",
                                             kname    => "Linux",
-                                            kvers    => "3.19.0-32-generic",
+                                            kvers    => "3.16.0-4-amd64",
                                             osflag   => "linux",
-                                            oslabel  => "LinuxMint",
+                                            oslabel  => "Debian",
                                             osname   => "GNU/Linux",
-                                            osvers   => 17.3,
+                                            osvers   => "8.0",
                                             source   => {
                                                           "cat /etc/.issue" => "",
-                                                          "cat /etc/issue"  => "Linux Mint 17.3 Rosa \\n \\l",
-                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 17.3 Rosa\nRelease:\t17.3\nCodename:\trosa",
-                                                          "uname -a"        => "Linux backpacker 3.19.0-32-generic #37~14.04.1-Ubuntu SMP Thu Oct 22 09:41:40 UTC 2015 x86_64 x86_64 x86_64 GNU/Linux",
+                                                          "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
+                                                          "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
+                                                          "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.36-1+deb8u2 (2016-10-19) x86_64 GNU/Linux",
                                                           "uname -m"        => "x86_64",
                                                           "uname -o"        => "GNU/Linux",
-                                                          "uname -r"        => "3.19.0-32-generic",
+                                                          "uname -r"        => "3.16.0-4-amd64",
                                                           "uname -s"        => "Linux",
                                                         },
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::NumericLevel",
       "func.scenario_module_md5sum"    => "d4c1a3955e444badfcfc9399ad49379b",
-      "func.scenario_module_mtime"     => 1498961728,
+      "func.scenario_module_mtime"     => 1499219367,
       "func.scenario_module_sha1sum"   => "5d5db7ba9a4229c19df61542f84537d6596f8ac0",
       "func.scenario_module_sha256sum" => "a6efeb768a00fb37f6801e6aa555b5daaae141235f27a746936fecf226630657",
-      "func.time_end"                  => 1499940790.34339,
+      "func.time_end"                  => 1501567515.66481,
       "func.time_factor"               => 1000000000,
-      "func.time_start"                => 1499940790.28577,
+      "func.time_start"                => 1501567515.61265,
       "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, "/s", "ns"],
       "table.fields"                   => ["dataset", "rate", "time", "vs_slowest", "errors", "samples"],
